@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/GenericInterface/Invoker/Test.pm - GenericInterface test data Invoker backend
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: Test.pm,v 1.12 2011-03-17 13:32:19 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::GenericInterface::Invoker::Test::Test;
@@ -13,18 +16,22 @@ use warnings;
 
 use Kernel::System::VariableCheck qw(IsString IsStringWithData);
 
-# prevent 'Used once' warning for Kernel::OM
-use Kernel::System::ObjectManager;
-
-our $ObjectManagerDisabled = 1;
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.12 $) [1];
 
 =head1 NAME
 
 Kernel::GenericInterface::Invoker::Test::Test - GenericInterface test Invoker backend
 
+=head1 SYNOPSIS
+
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
+
+=cut
+
+=item new()
 
 usually, you want to create an instance of this
 by using Kernel::GenericInterface::Invoker->new();
@@ -39,21 +46,23 @@ sub new {
     bless( $Self, $Type );
 
     # check needed params
-    if ( !$Param{DebuggerObject} ) {
-        return {
-            Success      => 0,
-            ErrorMessage => "Got no DebuggerObject!"
-        };
-    }
+    for my $Needed (qw(DebuggerObject MainObject TimeObject)) {
+        if ( !$Param{$Needed} ) {
+            return {
+                Success      => 0,
+                ErrorMessage => "Got no $Needed!"
+            };
+        }
 
-    $Self->{DebuggerObject} = $Param{DebuggerObject};
+        $Self->{$Needed} = $Param{$Needed};
+    }
 
     return $Self;
 }
 
-=head2 PrepareRequest()
+=item PrepareRequest()
 
-prepare the invocation of the configured remote web service.
+prepare the invocation of the configured remote webservice.
 
     my $Result = $InvokerObject->PrepareRequest(
         Data => {                               # data payload
@@ -90,7 +99,7 @@ sub PrepareRequest {
 
     # check request for system time
     if ( IsStringWithData( $Param{Data}->{GetSystemTime} ) && $Param{Data}->{GetSystemTime} ) {
-        $ReturnData{SystemTime} = $Kernel::OM->Create('Kernel::System::DateTime')->ToEpoch();
+        $ReturnData{SystemTime} = $Self->{TimeObject}->SystemTime();
     }
 
     return {
@@ -99,13 +108,13 @@ sub PrepareRequest {
     };
 }
 
-=head2 HandleResponse()
+=item HandleResponse()
 
-handle response data of the configured remote web service.
+handle response data of the configured remote webservice.
 
     my $Result = $InvokerObject->HandleResponse(
-        ResponseSuccess      => 1,              # success status of the remote web service
-        ResponseErrorMessage => '',             # in case of web service error
+        ResponseSuccess      => 1,              # success status of the remote webservice
+        ResponseErrorMessage => '',             # in case of webservice error
         Data => {                               # data payload
             ...
         },
@@ -127,12 +136,10 @@ sub HandleResponse {
     # if there was an error in the response, forward it
     if ( !$Param{ResponseSuccess} ) {
         if ( !IsStringWithData( $Param{ResponseErrorMessage} ) ) {
-
             return $Self->{DebuggerObject}->Error(
                 Summary => 'Got response error, but no response error message!',
             );
         }
-
         return {
             Success      => 0,
             ErrorMessage => $Param{ResponseErrorMessage},
@@ -141,7 +148,6 @@ sub HandleResponse {
 
     # we need a TicketNumber
     if ( !IsStringWithData( $Param{Data}->{TicketNumber} ) ) {
-
         return $Self->{DebuggerObject}->Error( Summary => 'Got no TicketNumber!' );
     }
 
@@ -153,7 +159,6 @@ sub HandleResponse {
     # check Action
     if ( IsStringWithData( $Param{Data}->{Action} ) ) {
         if ( $Param{Data}->{Action} !~ m{ \A ( .*? ) Test \z }xms ) {
-
             return $Self->{DebuggerObject}->Error(
                 Summary => 'Got Action but it is not in required format!',
             );
@@ -169,12 +174,20 @@ sub HandleResponse {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+
+=cut
+
+=head1 VERSION
+
+$Revision: 1.12 $ $Date: 2011-03-17 13:32:19 $
 
 =cut
