@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketZoom.pm - to get a closer view
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
 # --
-# $Id: AgentTicketZoom.pm,v 1.140 2010/11/26 05:43:46 martin Exp $
+# $Id: AgentTicketZoom.pm,v 1.177.2.2 2013-01-02 13:02:46 mn Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,9 +18,12 @@ use Kernel::System::CustomerUser;
 use Kernel::System::LinkObject;
 use Kernel::System::EmailParser;
 use Kernel::System::SystemAddress;
+use Kernel::System::DynamicField;
+use Kernel::System::DynamicField::Backend;
+use Kernel::System::VariableCheck qw(:all);
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.140 $) [1];
+$VERSION = qw($Revision: 1.177.2.2 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -73,12 +76,18 @@ sub new {
     if ( !$Self->{TicketID} && $Self->{ParamObject}->GetParam( Param => 'TicketNumber' ) ) {
         $Self->{TicketID} = $Self->{TicketObject}->TicketIDLookup(
             TicketNumber => $Self->{ParamObject}->GetParam( Param => 'TicketNumber' ),
-            UserID => $Self->{UserID},
+            UserID       => $Self->{UserID},
         );
     }
     $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(%Param);
     $Self->{LinkObject}         = Kernel::System::LinkObject->new(%Param);
     $Self->{SystemAddress}      = Kernel::System::SystemAddress->new(%Param);
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
+    $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
+
+    # get dynamic field config for frontend module
+    $Self->{DynamicFieldFilter}
+        = $Self->{ConfigObject}->Get("Ticket::Frontend::AgentTicketZoom")->{DynamicField};
 
     return $Self;
 }
@@ -107,9 +116,12 @@ sub Run {
     }
 
     # get ticket attributes
-    my %Ticket = $Self->{TicketObject}->TicketGet( TicketID => $Self->{TicketID} );
+    my %Ticket = $Self->{TicketObject}->TicketGet(
+        TicketID      => $Self->{TicketID},
+        DynamicFields => 1,
+    );
 
-    # get ack actions
+    # get acl actions
     $Self->{TicketObject}->TicketAcl(
         Data          => '-',
         Action        => $Self->{Action},
@@ -120,6 +132,27 @@ sub Run {
     );
     my %AclAction = $Self->{TicketObject}->TicketAclActionData();
 
+    # check if ACL resctictions if exist
+    if ( IsHashRefWithData( \%AclAction ) ) {
+
+        # show error screen if ACL prohibits this action
+        if ( defined $AclAction{ $Self->{Action} } && $AclAction{ $Self->{Action} } eq '0' ) {
+            return $Self->{LayoutObject}->NoPermission( WithHeader => 'yes' );
+        }
+    }
+
+    # mark shown ticket as seen
+    if ( $Self->{Subaction} eq 'TicketMarkAsSeen' ) {
+        my $Success = $Self->_TicketItemSeen( TicketID => $Self->{TicketID} );
+
+        return $Self->{LayoutObject}->Attachment(
+            ContentType => 'text/html',
+            Content     => $Success,
+            Type        => 'inline',
+            NoCache     => 1,
+        );
+    }
+
     # mark shown article as seen
     if ( $Self->{Subaction} eq 'MarkAsSeen' ) {
         my $Success = $Self->_ArticleItemSeen( ArticleID => $Self->{ArticleID} );
@@ -135,7 +168,10 @@ sub Run {
     # article update
     elsif ( $Self->{Subaction} eq 'ArticleUpdate' ) {
         my $Count = $Self->{ParamObject}->GetParam( Param => 'Count' );
-        my %Article = $Self->{TicketObject}->ArticleGet( ArticleID => $Self->{ArticleID} );
+        my %Article = $Self->{TicketObject}->ArticleGet(
+            ArticleID     => $Self->{ArticleID},
+            DynamicFields => 0,
+        );
         $Article{Count} = $Count;
 
         # get attachment index (without attachments)
@@ -298,7 +334,10 @@ sub Run {
         }
 
         # get article data
-        my %Article = $Self->{TicketObject}->ArticleGet( ArticleID => $Self->{ArticleID} );
+        my %Article = $Self->{TicketObject}->ArticleGet(
+            ArticleID     => $Self->{ArticleID},
+            DynamicFields => 0,
+        );
 
         # check if article data exists
         if ( !%Article ) {
@@ -342,8 +381,6 @@ sub MaskAgentZoom {
     my %StandardResponses
         = $Self->{QueueObject}->GetStandardResponses( QueueID => $Ticket{QueueID} );
 
-    $Ticket{TicketTimeUnits} = $Self->{TicketObject}->TicketAccountedTimeGet(%Ticket);
-
     # owner info
     my %OwnerInfo = $Self->{UserObject}->GetUserData(
         UserID => $Ticket{OwnerID},
@@ -361,6 +398,7 @@ sub MaskAgentZoom {
         TicketID                   => $Self->{TicketID},
         StripPlainBodyAsAttachment => $Self->{StripPlainBodyAsAttachment},
         UserID                     => $Self->{UserID},
+        DynamicFields => 0,    # fetch later only for the article(s) to display
     );
 
     # add counter
@@ -384,7 +422,7 @@ sub MaskAgentZoom {
             # ignore system sender type
             next ARTICLE
                 if $Self->{ConfigObject}->Get('Ticket::NewArticleIgnoreSystemSender')
-                    && $Article->{SenderType} eq 'system';
+                && $Article->{SenderType} eq 'system';
 
             # get article flags
             my %ArticleFlag = $Self->{TicketObject}->ArticleFlagGet(
@@ -530,10 +568,18 @@ sub MaskAgentZoom {
             Article           => \%Article,
             AclAction         => \%AclAction,
             StandardResponses => \%StandardResponses,
+            ActualArticleID   => $ArticleID,
             Type              => 'Static',
         );
     }
 
+    if ( $Self->{ZoomExpand} ) {
+        $Self->{LayoutObject}->Block(
+            Name => 'TicketItemMarkAsSeen',
+            Data => { TicketID => $Ticket{TicketID} },
+        );
+    }
+
     # age design
     $Ticket{Age} = $Self->{LayoutObject}->CustomerAge( Age => $Ticket{Age}, Space => ' ' );
 
@@ -585,8 +631,9 @@ sub MaskAgentZoom {
         $MoveQueues{0}
             = '- ' . $Self->{LayoutObject}->{LanguageObject}->Get('Move') . ' -';
         $Param{MoveQueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
-            Name => 'DestQueueID',
-            Data => \%MoveQueues,
+            Name           => 'DestQueueID',
+            Data           => \%MoveQueues,
+            CurrentQueueID => $Ticket{QueueID},
         );
     }
     if (
@@ -617,6 +664,15 @@ sub MaskAgentZoom {
         }
     }
 
+    # show created by if different then User ID 1
+    if ( $Ticket{CreateBy} > 1 ) {
+        $Ticket{CreatedByUser} = $Self->{UserObject}->UserName( UserID => $Ticket{CreateBy} );
+        $Self->{LayoutObject}->Block(
+            Name => 'CreatedBy',
+            Data => {%Ticket},
+        );
+    }
+
     # ticket type
     if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
         $Self->{LayoutObject}->Block(
@@ -696,14 +752,66 @@ sub MaskAgentZoom {
         );
     }
 
+    # test access to frontend module for Customer
+    my $Access = $Self->{LayoutObject}->Permission(
+        Action => 'AgentTicketCustomer',
+        Type   => 'rw',
+    );
+
+    # acl check
+    if (
+        $Access
+        && defined $AclAction{AgentTicketCustomer}
+        && !$AclAction{AgentTicketCustomer}
+        )
+    {
+        $Access = 0;
+    }
+
+    if ($Access) {
+
+        # test access to ticket
+        my $Config = $Self->{ConfigObject}->Get('Ticket::Frontend::AgentTicketCustomer');
+        if ( $Config->{Permission} ) {
+            my $OK = $Self->{TicketObject}->Permission(
+                Type     => $Config->{Permission},
+                TicketID => $Ticket{TicketID},
+                UserID   => $Self->{UserID},
+                LogNo    => 1,
+            );
+            if ( !$OK ) {
+                $Access = 0;
+            }
+        }
+    }
+
+    # define proper DTL block based on permissions
+    my $CustomerIDBlock = $Access ? 'CustomerIDRW' : 'CustomerIDRO';
+    $Self->{LayoutObject}->Block(
+        Name => $CustomerIDBlock,
+        Data => \%Ticket,
+    );
+
+    # show total accounted time if feature is active:
+    if ( $Self->{ConfigObject}->Get('Ticket::Frontend::AccountTime') ) {
+        $Ticket{TicketTimeUnits} = $Self->{TicketObject}->TicketAccountedTimeGet(%Ticket);
+        $Self->{LayoutObject}->Block(
+            Name => 'TotalAccountedTime',
+            Data => \%Ticket,
+        );
+    }
+
     # show pending until, if set:
     if ( $Ticket{UntilTime} ) {
         if ( $Ticket{UntilTime} < -1 ) {
             $Ticket{PendingUntilClass} = 'Warning';
         }
+        $Ticket{UntilTimeHuman} = $Self->{TimeObject}->SystemTime2TimeStamp(
+            SystemTime => ( $Ticket{UntilTime} + $Self->{TimeObject}->SystemTime() ),
+        );
         $Ticket{PendingUntil} .= $Self->{LayoutObject}->CustomerAge(
             Age   => $Ticket{UntilTime},
-            Space => '<br/>'
+            Space => ' '
         );
         $Self->{LayoutObject}->Block(
             Name => 'PendingUntil',
@@ -725,73 +833,71 @@ sub MaskAgentZoom {
         );
     }
 
-    # ticket free text
-    FREETEXT:
-    for my $Count ( 1 .. 16 ) {
-        next FREETEXT if !$Ticket{ 'TicketFreeText' . $Count };
-        $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeText' . $Count,
-            Data => { %Ticket, %AclAction },
+    # get the dynamic fields for ticket object
+    my $DynamicField = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid       => 1,
+        ObjectType  => ['Ticket'],
+        FieldFilter => $Self->{DynamicFieldFilter} || {},
+    );
+
+    # cycle trough the activated Dynamic Fields for ticket object
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{$DynamicField} ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+        next DYNAMICFIELD if !defined $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} };
+        next DYNAMICFIELD if $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} } eq '';
+
+        # get print string for this dynamic field
+        my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            Value              => $Ticket{ 'DynamicField_' . $DynamicFieldConfig->{Name} },
+            ValueMaxChars      => 25,
+            LayoutObject       => $Self->{LayoutObject},
         );
+
+        my $Label = $DynamicFieldConfig->{Label};
+
         $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeText',
+            Name => 'TicketDynamicField',
             Data => {
-                %Ticket, %AclAction,
-                TicketFreeKey  => $Ticket{ 'TicketFreeKey' . $Count },
-                TicketFreeText => $Ticket{ 'TicketFreeText' . $Count },
-                Count          => $Count,
+                Label => $Label,
             },
         );
-        if ( !$Self->{ConfigObject}->Get( 'TicketFreeText' . $Count . '::Link' ) ) {
+
+        if ( $ValueStrg->{Link} ) {
             $Self->{LayoutObject}->Block(
-                Name => 'TicketFreeTextPlain' . $Count,
-                Data => { %Ticket, %AclAction },
-            );
-            $Self->{LayoutObject}->Block(
-                Name => 'TicketFreeTextPlain',
+                Name => 'TicketDynamicFieldLink',
                 Data => {
-                    %Ticket, %AclAction,
-                    TicketFreeKey  => $Ticket{ 'TicketFreeKey' . $Count },
-                    TicketFreeText => $Ticket{ 'TicketFreeText' . $Count },
-                    Count          => $Count,
+                    Value                       => $ValueStrg->{Value},
+                    Title                       => $ValueStrg->{Title},
+                    Link                        => $ValueStrg->{Link},
+                    $DynamicFieldConfig->{Name} => $ValueStrg->{Title},
                 },
             );
         }
         else {
             $Self->{LayoutObject}->Block(
-                Name => 'TicketFreeTextLink' . $Count,
-                Data => { %Ticket, %AclAction },
-            );
-            $Self->{LayoutObject}->Block(
-                Name => 'TicketFreeTextLink',
+                Name => 'TicketDynamicFieldPlain',
                 Data => {
-                    %Ticket, %AclAction,
-                    TicketFreeTextLink => $Self->{ConfigObject}->Get(
-                        'TicketFreeText' . $Count . '::Link'
-                    ),
-                    TicketFreeKey  => $Ticket{ 'TicketFreeKey' . $Count },
-                    TicketFreeText => $Ticket{ 'TicketFreeText' . $Count },
-                    Count          => $Count,
+                    Value => $ValueStrg->{Value},
+                    Title => $ValueStrg->{Title},
                 },
             );
         }
-    }
 
-    # ticket free time
-    FREETIME:
-    for my $Count ( 1 .. 6 ) {
-        next FREETIME if !$Ticket{ 'TicketFreeTime' . $Count };
+        # example of dynamic fields order customization
         $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeTime' . $Count,
-            Data => { %Ticket, %AclAction },
-        );
-        $Self->{LayoutObject}->Block(
-            Name => 'TicketFreeTime',
+            Name => 'TicketDynamicField_' . $DynamicFieldConfig->{Name},
             Data => {
-                %Ticket, %AclAction,
-                TicketFreeTimeKey => $Self->{ConfigObject}->Get( 'TicketFreeTimeKey' . $Count ),
-                TicketFreeTime    => $Ticket{ 'TicketFreeTime' . $Count },
-                Count             => $Count,
+                Label => $Label,
+            },
+        );
+
+        $Self->{LayoutObject}->Block(
+            Name => 'TicketDynamicField_' . $DynamicFieldConfig->{Name} . '_Plain',
+            Data => {
+                Value => $ValueStrg->{Value},
+                Title => $ValueStrg->{Title},
             },
         );
     }
@@ -904,7 +1010,7 @@ sub MaskAgentZoom {
         # ignore system sender type
         next ARTICLE
             if $Self->{ConfigObject}->Get('Ticket::NewArticleIgnoreSystemSender')
-                && $Article->{SenderType} eq 'system';
+            && $Article->{SenderType} eq 'system';
 
         # get article flags
         my %ArticleFlag = $Self->{TicketObject}->ArticleFlagGet(
@@ -929,6 +1035,12 @@ sub MaskAgentZoom {
         );
     }
 
+    # init js
+    $Self->{LayoutObject}->Block(
+        Name => 'TicketZoomInit',
+        Data => {%Param},
+    );
+
     # return output
     return $Self->{LayoutObject}->Output(
         TemplateFile => 'AgentTicketZoom',
@@ -944,10 +1056,18 @@ sub _ArticleTree {
     my $ArticleMaxLimit = $Param{ArticleMaxLimit};
     my $ArticleID       = $Param{ArticleID};
 
+    my $TableClasses;
+    if ( $Self->{ConfigObject}->Get('Ticket::UseArticleColors') ) {
+        $TableClasses .= 'UseArticleColors';
+    }
+
     # build thread string
     $Self->{LayoutObject}->Block(
         Name => 'Tree',
-        Data => {%Param},
+        Data => {
+            %Param,
+            TableClasses => $TableClasses,
+        },
     );
 
     # check if expand/collapse view is usable (only for less then 300 articles)
@@ -1145,7 +1265,7 @@ sub _ArticleTree {
         my $Type = $Self->{ConfigObject}->Get('AttachmentDownloadType') || 'attachment';
 
         # if attachment will be forced to download, don't open a new download window!
-        my $Target = '';
+        my $Target = 'target="AttachmentWindow" ';
         if ( $Type =~ /inline/i ) {
             $Target = 'target="attachment" ';
         }
@@ -1207,6 +1327,22 @@ sub _ArticleTree {
     );
 }
 
+sub _TicketItemSeen {
+    my ( $Self, %Param ) = @_;
+
+    my @ArticleIDs = $Self->{TicketObject}->ArticleIndex(
+        TicketID => $Param{TicketID},
+    );
+
+    for my $ArticleID (@ArticleIDs) {
+        $Self->_ArticleItemSeen(
+            ArticleID => $ArticleID,
+        );
+    }
+
+    return 1;
+}
+
 sub _ArticleItemSeen {
     my ( $Self, %Param ) = @_;
 
@@ -1239,15 +1375,31 @@ sub _ArticleItem {
         Data => { %Param, %Article, %AclAction },
     );
 
+    # show created by if different from User ID 1
+    if ( $Article{CreatedBy} > 1 ) {
+        $Article{CreatedByUser} = $Self->{UserObject}->UserName( UserID => $Article{CreatedBy} );
+        $Self->{LayoutObject}->Block(
+            Name => 'ArticleCreatedBy',
+            Data => {%Article},
+        );
+    }
+
     # mark shown article as seen
     if ( $Param{Type} eq 'OnLoad' ) {
         $Self->_ArticleItemSeen( ArticleID => $Article{ArticleID} );
     }
     else {
-        $Self->{LayoutObject}->Block(
-            Name => 'ArticleItemMarkAsSeen',
-            Data => { %Param, %Article, %AclAction },
-        );
+        if (
+            !$Self->{ZoomExpand}
+            && defined $Param{ActualArticleID}
+            && $Param{ActualArticleID} == $Article{ArticleID}
+            )
+        {
+            $Self->{LayoutObject}->Block(
+                Name => 'ArticleItemMarkAsSeen',
+                Data => { %Param, %Article, %AclAction },
+            );
+        }
     }
 
     # show article actions
@@ -1312,7 +1464,7 @@ sub _ArticleItem {
                         Name                  => 'Reply',
                         Class                 => 'AsPopup PopupType_TicketAction',
                         Action                => 'AgentTicketCompose',
-                        FormID                => 'Reply',
+                        FormID                => 'Reply' . $Article{ArticleID},
                         ResponseElementID     => 'ResponseID',
                     },
                 );
@@ -1320,7 +1472,7 @@ sub _ArticleItem {
                     Name => 'ArticleReplyAsDropdownJS' . $Param{Type},
                     Data => {
                         %Ticket, %Article, %AclAction,
-                        FormID => 'Reply',
+                        FormID => 'Reply' . $Article{ArticleID},
                     },
                 );
 
@@ -1343,8 +1495,10 @@ sub _ArticleItem {
                     my @Addresses = $EmailParser->SplitAddressLine( Line => $Recipients );
                     ADDRESS:
                     for my $Address (@Addresses) {
+                        my $Email = $EmailParser->GetEmailAddress( Email => $Address );
+                        next if !$Email;
                         my $IsLocal = $Self->{SystemAddress}->SystemAddressIsLocalAddress(
-                            Address => $EmailParser->GetEmailAddress( Email => $Address ),
+                            Address => $Email,
                         );
                         next ADDRESS if $IsLocal;
                         $RecipientCount++;
@@ -1422,8 +1576,9 @@ sub _ArticleItem {
                     Name => 'ArticleMenu',
                     Data => {
                         %Ticket, %Article, %AclAction,
-                        Name  => 'Forward',
-                        Class => 'AsPopup PopupType_TicketAction',
+                        Description => 'Forward article via mail',
+                        Name        => 'Forward',
+                        Class       => 'AsPopup PopupType_TicketAction',
                         Link =>
                             'Action=AgentTicketForward;TicketID=$Data{"TicketID"};ArticleID=$Data{"ArticleID"}'
                     },
@@ -1469,8 +1624,9 @@ sub _ArticleItem {
                     Name => 'ArticleMenu',
                     Data => {
                         %Ticket, %Article, %AclAction,
-                        Name  => 'Bounce',
-                        Class => 'AsPopup PopupType_TicketAction',
+                        Description => 'Bounce Article to a different mail address',
+                        Name        => 'Bounce',
+                        Class       => 'AsPopup PopupType_TicketAction',
                         Link =>
                             'Action=AgentTicketBounce;TicketID=$Data{"TicketID"};ArticleID=$Data{"ArticleID"}'
                     },
@@ -1483,7 +1639,7 @@ sub _ArticleItem {
         }
     }
 
-    # check if phone link should be shown
+    # check if phone link (outbound) should be shown
     if (
         $Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketPhoneOutbound}
         && (
@@ -1524,9 +1680,60 @@ sub _ArticleItem {
                 Name => 'ArticleMenu',
                 Data => {
                     %Ticket, %Article, %AclAction,
-                    Name  => 'Phone Call Outbound',
-                    Class => 'AsPopup PopupType_TicketAction',
-                    Link  => 'Action=AgentTicketPhoneOutbound;TicketID=$Data{"TicketID"}'
+                    Description => 'Phone Call Outbound',
+                    Name        => 'Phone Call Outbound',
+                    Class       => 'AsPopup PopupType_TicketAction',
+                    Link        => 'Action=AgentTicketPhoneOutbound;TicketID=$Data{"TicketID"}'
+                },
+            );
+        }
+    }
+
+    # check if phone link (inbound) should be shown
+    if (
+        $Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketPhoneInbound}
+        && (
+            !defined $AclAction{AgentTicketPhoneInbound}
+            || $AclAction{AgentTicketPhoneInbound}
+        )
+        )
+    {
+        my $Access = 1;
+        my $Config = $Self->{ConfigObject}->Get('Ticket::Frontend::AgentTicketPhoneInbound');
+        if ( $Config->{Permission} ) {
+            my $OK = $Self->{TicketObject}->TicketPermission(
+                Type     => $Config->{Permission},
+                TicketID => $Ticket{TicketID},
+                UserID   => $Self->{UserID},
+                LogNo    => 1,
+            );
+            if ( !$OK ) {
+                $Access = 0;
+            }
+        }
+        if ( $Config->{RequiredLock} ) {
+            my $Locked = $Self->{TicketObject}->TicketLockGet(
+                TicketID => $Ticket{TicketID}
+            );
+            if ($Locked) {
+                my $AccessOk = $Self->{TicketObject}->OwnerCheck(
+                    TicketID => $Ticket{TicketID},
+                    OwnerID  => $Self->{UserID},
+                );
+                if ( !$AccessOk ) {
+                    $Access = 0;
+                }
+            }
+        }
+        if ($Access) {
+            $Self->{LayoutObject}->Block(
+                Name => 'ArticleMenu',
+                Data => {
+                    %Ticket, %Article, %AclAction,
+                    Description => 'Phone Call Inbound',
+                    Name        => 'Phone Call Inbound',
+                    Class       => 'AsPopup PopupType_TicketAction',
+                    Link        => 'Action=AgentTicketPhoneInbound;TicketID=$Data{"TicketID"}'
                 },
             );
         }
@@ -1542,7 +1749,8 @@ sub _ArticleItem {
             Name => 'ArticleMenu',
             Data => {
                 %Ticket, %Article, %AclAction,
-                Name => 'Split',
+                Description => 'Split this article',
+                Name        => 'Split',
                 Link =>
                     'Action=AgentTicketPhone;TicketID=$Data{"TicketID"};ArticleID=$Data{"ArticleID"};LinkTicketID=$Data{"TicketID"}'
             },
@@ -1566,8 +1774,9 @@ sub _ArticleItem {
                 Name => 'ArticleMenu',
                 Data => {
                     %Ticket, %Article, %AclAction,
-                    Name  => 'Print',
-                    Class => 'AsPopup PopupType_TicketAction',
+                    Description => 'Print this article',
+                    Name        => 'Print',
+                    Class       => 'AsPopup PopupType_TicketAction',
                     Link =>
                         'Action=AgentTicketPrint;TicketID=$Data{"TicketID"};ArticleID=$Data{"ArticleID"}'
                 },
@@ -1578,6 +1787,7 @@ sub _ArticleItem {
     # check if plain link should be shown
     if (
         $Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketPlain}
+        && $Self->{ConfigObject}->Get('Ticket::Frontend::PlainView')
         && ( !defined $AclAction{AgentTicketPlain} || $AclAction{AgentTicketPlain} )
         && $Article{ArticleType} =~ /email/i
         )
@@ -1595,9 +1805,10 @@ sub _ArticleItem {
                 Name => 'ArticleMenu',
                 Data => {
                     %Ticket, %Article, %AclAction,
-                    Name  => 'Plain Format',
-                    Class => 'AsPopup PopupType_TicketAction',
-                    Link  => $Link,
+                    Description => 'View the source for this Article',
+                    Name        => 'Plain Format',
+                    Class       => 'AsPopup PopupType_TicketAction',
+                    Link        => $Link,
                 },
             );
         }
@@ -1618,7 +1829,11 @@ sub _ArticleItem {
     }
 
     # show accounted article time
-    if ( $Self->{ConfigObject}->Get('Ticket::ZoomTimeDisplay') ) {
+    if (
+        $Self->{ConfigObject}->Get('Ticket::ZoomTimeDisplay')
+        && $Self->{ConfigObject}->Get('Ticket::Frontend::AccountTime')
+        )
+    {
         my $ArticleTime = $Self->{TicketObject}->ArticleAccountedTimeGet(
             ArticleID => $Article{ArticleID}
         );
@@ -1631,66 +1846,101 @@ sub _ArticleItem {
         );
     }
 
-    # show article free text
-    FREETEXT:
-    for my $Count ( 1 .. 3 ) {
-        next FREETEXT if !$Article{"ArticleFreeText$Count"};
+    # get the dynamic fields for article object
+    my $DynamicField = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+        Valid       => 1,
+        ObjectType  => ['Article'],
+        FieldFilter => $Self->{DynamicFieldFilter} || {},
+    );
+
+    # cycle trough the activated Dynamic Fields
+    DYNAMICFIELD:
+    for my $DynamicFieldConfig ( @{$DynamicField} ) {
+        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+
+        my $Value = $Self->{BackendObject}->ValueGet(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            ObjectID           => $Article{ArticleID},
+        );
+
+        next if !$Value;
+        next if $Value eq '';
+
+        # get print string for this dynamic field
+        my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            Value              => $Value,
+            ValueMaxChars      => 160,
+            LayoutObject       => $Self->{LayoutObject},
+        );
+
+        my $Label = $DynamicFieldConfig->{Label};
+
         $Self->{LayoutObject}->Block(
-            Name => 'ArticleFreeText',
+            Name => 'ArticleDynamicField',
             Data => {
-                Key   => $Article{"ArticleFreeKey$Count"},
-                Value => $Article{"ArticleFreeText$Count"},
+                Label => $Label,
             },
         );
-    }
 
-    # add block for attachments
-    if ( $Article{Atms} && %{ $Article{Atms} } ) {
-        my %AtmIndex = %{ $Article{Atms} };
+        if ( $ValueStrg->{Link} ) {
+
+            # output link element
+            $Self->{LayoutObject}->Block(
+                Name => 'ArticleDynamicFieldLink',
+                Data => {
+                    Value                       => $ValueStrg->{Value},
+                    Title                       => $ValueStrg->{Title},
+                    Link                        => $ValueStrg->{Link},
+                    $DynamicFieldConfig->{Name} => $ValueStrg->{Title}
+                },
+            );
+        }
+        else {
+
+            # output non link element
+            $Self->{LayoutObject}->Block(
+                Name => 'ArticleDynamicFieldPlain',
+                Data => {
+                    Value => $ValueStrg->{Value},
+                    Title => $ValueStrg->{Title},
+                },
+            );
+        }
+
+        # example of dynamic fields order customization
         $Self->{LayoutObject}->Block(
-            Name => 'ArticleAttachment',
-            Data => {},
+            Name => 'ArticleDynamicField' . $DynamicFieldConfig->{Name},
+            Data => {
+                Label => $Label,
+                Value => $ValueStrg->{Value},
+                Title => $ValueStrg->{Title},
+            },
         );
 
-        my $Config = $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleAttachmentModule');
-        ATTACHMENT:
-        for my $FileID ( sort keys %AtmIndex ) {
-            my %File = %{ $AtmIndex{$FileID} };
+        if ( $ValueStrg->{Link} ) {
+
+            # output link element
             $Self->{LayoutObject}->Block(
-                Name => 'ArticleAttachmentRow',
-                Data => \%File,
+                Name => 'ArticleDynamicField' . $DynamicFieldConfig->{Name} . 'Link',
+                Data => {
+                    Value                       => $ValueStrg->{Value},
+                    Title                       => $ValueStrg->{Title},
+                    Link                        => $ValueStrg->{Link},
+                    $DynamicFieldConfig->{Name} => $ValueStrg->{Title}
+                },
             );
+        }
+        else {
 
-            # run article attachment modules
-            next ATTACHMENT if ref $Config ne 'HASH';
-            my %Jobs = %{$Config};
-            JOB:
-            for my $Job ( sort keys %Jobs ) {
-
-                # load module
-                if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
-                    return $Self->{LayoutObject}->ErrorScreen();
-                }
-                my $Object = $Jobs{$Job}->{Module}->new(
-                    %{$Self},
-                    TicketID  => $Self->{TicketID},
-                    ArticleID => $Article{ArticleID},
-                );
-
-                # run module
-                my %Data = $Object->Run(
-                    File => {
-                        %File,
-                        FileID => $FileID,
-                    },
-                    Article => \%Article,
-                );
-                next JOB if !%Data;
-                $Self->{LayoutObject}->Block(
-                    Name => $Data{Block} || 'ArticleAttachmentRowLink',
-                    Data => {%Data},
-                );
-            }
+            # output non link element
+            $Self->{LayoutObject}->Block(
+                Name => 'ArticleDynamicField' . $DynamicFieldConfig->{Name} . 'Plain',
+                Data => {
+                    Value => $ValueStrg->{Value},
+                    Title => $ValueStrg->{Title},
+                },
+            );
         }
     }
 
@@ -1737,6 +1987,77 @@ sub _ArticleItem {
         }
     }
 
+    %Article = $Self->{TicketObject}->ArticleGet(
+        ArticleID     => $Article{ArticleID},
+        DynamicFields => 0,
+    );
+
+    # get attachment index (without attachments)
+    my %AtmIndex = $Self->{TicketObject}->ArticleAttachmentIndex(
+        ArticleID                  => $Article{ArticleID},
+        StripPlainBodyAsAttachment => $Self->{StripPlainBodyAsAttachment},
+        Article                    => \%Article,
+        UserID                     => $Self->{UserID},
+    );
+    $Article{Atms} = \%AtmIndex;
+
+    # add block for attachments
+    if ( $Article{Atms} && %{ $Article{Atms} } ) {
+        my %AtmIndex = %{ $Article{Atms} };
+        $Self->{LayoutObject}->Block(
+            Name => 'ArticleAttachment',
+            Data => {},
+        );
+
+        my $Config = $Self->{ConfigObject}->Get('Ticket::Frontend::ArticleAttachmentModule');
+        ATTACHMENT:
+        for my $FileID ( sort keys %AtmIndex ) {
+            my %File = %{ $AtmIndex{$FileID} };
+            $Self->{LayoutObject}->Block(
+                Name => 'ArticleAttachmentRow',
+                Data => \%File,
+            );
+
+            # run article attachment modules
+            next ATTACHMENT if ref $Config ne 'HASH';
+            my %Jobs = %{$Config};
+            JOB:
+            for my $Job ( sort keys %Jobs ) {
+
+                # load module
+                if ( !$Self->{MainObject}->Require( $Jobs{$Job}->{Module} ) ) {
+                    return $Self->{LayoutObject}->ErrorScreen();
+                }
+                my $Object = $Jobs{$Job}->{Module}->new(
+                    %{$Self},
+                    TicketID  => $Self->{TicketID},
+                    ArticleID => $Article{ArticleID},
+                );
+
+                # run module
+                my %Data = $Object->Run(
+                    File => {
+                        %File,
+                        FileID => $FileID,
+                    },
+                    Article => \%Article,
+                );
+
+                # check for the display of the filesize
+                if ( $Job eq '2-HTML-Viewer' && !%Data ) {
+                    $Data{DataFileSize} = ", " . $File{Filesize};
+                }
+                elsif ( $Job eq '2-HTML-Viewer' && %Data ) {
+                    $Data{DataFileSize} = ", " . $Data{Filesize};
+                }
+                $Self->{LayoutObject}->Block(
+                    Name => $Data{Block} || 'ArticleAttachmentRowLink',
+                    Data => {%Data},
+                );
+            }
+        }
+    }
+
     # show body as html or plain text
     my $ViewMode = 'BodyHTML';
 
