@@ -1,9 +1,12 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Kernel/System/Priority.pm - all ticket priority function
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: Priority.pm,v 1.36 2012-03-29 11:11:55 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::System::Priority;
@@ -11,31 +14,65 @@ package Kernel::System::Priority;
 use strict;
 use warnings;
 
-our @ObjectDependencies = (
-    'Kernel::Config',
-    'Kernel::System::Cache',
-    'Kernel::System::DB',
-    'Kernel::System::Log',
-    'Kernel::System::SysConfig',
-    'Kernel::System::Valid',
-);
+use Kernel::System::CacheInternal;
+use Kernel::System::SysConfig;
+use Kernel::System::Time;
+use Kernel::System::Valid;
+
+use vars qw(@ISA $VERSION);
+$VERSION = qw($Revision: 1.36 $) [1];
 
 =head1 NAME
 
 Kernel::System::Priority - priority lib
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 All ticket priority functions.
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
+
+=cut
+
+=item new()
 
 create an object
 
-    my $PriorityObject = $Kernel::OM->Get('Kernel::System::Priority');
+    use Kernel::Config;
+    use Kernel::System::Encode;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::DB;
+    use Kernel::System::Priority;
 
+    my $ConfigObject = Kernel::Config->new();
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        EncodeObject => $EncodeObject,
+        LogObject    => $LogObject,
+        MainObject   => $MainObject,
+    );
+    my $PriorityObject = Kernel::System::Priority->new(
+        ConfigObject => $ConfigObject,
+        LogObject    => $LogObject,
+        DBObject     => $DBObject,
+        MainObject   => $MainObject,
+        EncodeObject => $EncodeObject,
+    );
 
 =cut
 
@@ -46,13 +83,21 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    $Self->{CacheType} = 'Priority';
-    $Self->{CacheTTL}  = 60 * 60 * 24 * 20;
+    # check needed objects
+    for (qw(DBObject ConfigObject LogObject MainObject EncodeObject)) {
+        $Self->{$_} = $Param{$_} || die "Got no $_!";
+    }
+    $Self->{ValidObject}         = Kernel::System::Valid->new(%Param);
+    $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
+        %Param,
+        Type => 'Priority',
+        TTL  => 60 * 60 * 24 * 20,
+    );
 
     return $Self;
 }
 
-=head2 PriorityList()
+=item PriorityList()
 
 return a priority list as hash
 
@@ -80,33 +125,27 @@ sub PriorityList {
     }
 
     # check cache
-    my $Cache = $Kernel::OM->Get('Kernel::System::Cache')->Get(
-        Type => $Self->{CacheType},
-        Key  => $CacheKey,
+    my $Cache = $Self->{CacheInternalObject}->Get(
+        Key => $CacheKey,
     );
     return %{$Cache} if $Cache;
 
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # create sql
     my $SQL = 'SELECT id, name FROM ticket_priority ';
     if ( $Param{Valid} ) {
-        $SQL
-            .= "WHERE valid_id IN ( ${\(join ', ', $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet())} )";
+        $SQL .= "WHERE valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
     }
 
-    return if !$DBObject->Prepare( SQL => $SQL );
+    return if !$Self->{DBObject}->Prepare( SQL => $SQL );
 
     # fetch the result
     my %Data;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[1];
     }
 
     # set cache
-    $Kernel::OM->Get('Kernel::System::Cache')->Set(
-        Type  => $Self->{CacheType},
-        TTL   => $Self->{CacheTTL},
+    $Self->{CacheInternalObject}->Set(
         Key   => $CacheKey,
         Value => \%Data,
     );
@@ -114,7 +153,7 @@ sub PriorityList {
     return %Data;
 }
 
-=head2 PriorityGet()
+=item PriorityGet()
 
 get a priority
 
@@ -131,25 +170,19 @@ sub PriorityGet {
     # check needed stuff
     for (qw(PriorityID UserID)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
 
     # check cache
-    my $Cache = $Kernel::OM->Get('Kernel::System::Cache')->Get(
-        Type => $Self->{CacheType},
-        Key  => 'PriorityGet' . $Param{PriorityID},
+    my $Cache = $Self->{CacheInternalObject}->Get(
+        Key => 'PriorityGet' . $Param{PriorityID},
     );
     return %{$Cache} if $Cache;
 
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
     # ask database
-    return if !$DBObject->Prepare(
+    return if !$Self->{DBObject}->Prepare(
         SQL => 'SELECT id, name, valid_id, create_time, create_by, change_time, change_by '
             . 'FROM ticket_priority WHERE id = ?',
         Bind  => [ \$Param{PriorityID} ],
@@ -158,7 +191,7 @@ sub PriorityGet {
 
     # fetch the result
     my %Data;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $Data{ID}         = $Row[0];
         $Data{Name}       = $Row[1];
         $Data{ValidID}    = $Row[2];
@@ -169,9 +202,7 @@ sub PriorityGet {
     }
 
     # set cache
-    $Kernel::OM->Get('Kernel::System::Cache')->Set(
-        Type  => $Self->{CacheType},
-        TTL   => $Self->{CacheTTL},
+    $Self->{CacheInternalObject}->Set(
         Key   => 'PriorityGet' . $Param{PriorityID},
         Value => \%Data,
     );
@@ -179,7 +210,7 @@ sub PriorityGet {
     return %Data;
 }
 
-=head2 PriorityAdd()
+=item PriorityAdd()
 
 add a ticket priority
 
@@ -197,17 +228,12 @@ sub PriorityAdd {
     # check needed stuff
     for (qw(Name ValidID UserID)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
 
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
-
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL => 'INSERT INTO ticket_priority (name, valid_id, create_time, create_by, '
             . 'change_time, change_by) VALUES '
             . '(?, ?, current_timestamp, ?, current_timestamp, ?)',
@@ -216,8 +242,8 @@ sub PriorityAdd {
         ],
     );
 
-    # get new priority id
-    return if !$DBObject->Prepare(
+    # get new state id
+    return if !$Self->{DBObject}->Prepare(
         SQL   => 'SELECT id FROM ticket_priority WHERE name = ?',
         Bind  => [ \$Param{Name} ],
         Limit => 1,
@@ -225,21 +251,19 @@ sub PriorityAdd {
 
     # fetch the result
     my $ID;
-    while ( my @Row = $DBObject->FetchrowArray() ) {
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
         $ID = $Row[0];
     }
 
     return if !$ID;
 
     # delete cache
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => $Self->{CacheType},
-    );
+    $Self->{CacheInternalObject}->CleanUp();
 
     return $ID;
 }
 
-=head2 PriorityUpdate()
+=item PriorityUpdate()
 
 update a existing ticket priority
 
@@ -247,6 +271,7 @@ update a existing ticket priority
         PriorityID     => 123,
         Name           => 'New Prio',
         ValidID        => 1,
+        CheckSysConfig => 0,   # (optional) default 1
         UserID         => 1,
     );
 
@@ -258,17 +283,17 @@ sub PriorityUpdate {
     # check needed stuff
     for (qw(PriorityID Name ValidID UserID)) {
         if ( !$Param{$_} ) {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => "Need $_!"
-            );
+            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
             return;
         }
     }
 
-    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+    # check CheckSysConfig param
+    if ( !defined $Param{CheckSysConfig} ) {
+        $Param{CheckSysConfig} = 1;
+    }
 
-    return if !$DBObject->Do(
+    return if !$Self->{DBObject}->Do(
         SQL => 'UPDATE ticket_priority SET name = ?, valid_id = ?, '
             . 'change_time = current_timestamp, change_by = ? WHERE id = ?',
         Bind => [
@@ -277,14 +302,25 @@ sub PriorityUpdate {
     );
 
     # delete cache
-    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
-        Type => $Self->{CacheType},
+    $Self->{CacheInternalObject}->CleanUp();
+
+    # check all sysconfig options
+    return 1 if !$Param{CheckSysConfig};
+
+    # create a time object locally, needed for the local SysConfigObject
+    my $TimeObject = Kernel::System::Time->new( %{$Self} );
+
+    # create a sysconfig object locally for performance reasons
+    my $SysConfigObject = Kernel::System::SysConfig->new(
+        %{$Self},
+        TimeObject => $TimeObject,
     );
 
-    return 1;
+    # check all sysconfig options and correct them automatically if neccessary
+    $SysConfigObject->ConfigItemCheckAll();
 }
 
-=head2 PriorityLookup()
+=item PriorityLookup()
 
 returns the id or the name of a priority
 
@@ -303,10 +339,7 @@ sub PriorityLookup {
 
     # check needed stuff
     if ( !$Param{Priority} && !$Param{PriorityID} ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => 'Need Priority or PriorityID!'
-        );
+        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Priority or PriorityID!' );
         return;
     }
 
@@ -332,7 +365,7 @@ sub PriorityLookup {
 
     # check if data exists
     if ( !defined $ReturnData ) {
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
+        $Self->{LogObject}->Log(
             Priority => 'error',
             Message  => "No $Key for $Value found!",
         );
@@ -344,12 +377,20 @@ sub PriorityLookup {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+
+=cut
+
+=head1 VERSION
+
+$Revision: 1.36 $ $Date: 2012-03-29 11:11:55 $
 
 =cut
