@@ -1,7 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
 # bin/otrs.PackageManager.pl - otrs package manager cmd version
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: otrs.PackageManager.pl,v 1.10 2010-10-14 08:54:15 bes Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -22,27 +24,42 @@
 use strict;
 use warnings;
 
+# use ../ as lib location
 use File::Basename;
+use File::Spec;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . '/Kernel/cpan-lib';
-use lib dirname($RealBin) . '/Custom';
 
-use File::Spec;
 use Getopt::Std;
 
-use Kernel::System::ObjectManager;
+use Kernel::Config;
+use Kernel::System::Encode;
+use Kernel::System::Log;
+use Kernel::System::Main;
+use Kernel::System::DB;
+use Kernel::System::Time;
+use Kernel::System::Package;
 
-# create object manager
-local $Kernel::OM = Kernel::System::ObjectManager->new(
-    'Kernel::System::Log' => {
-        LogPrefix => 'OTRS-otrs.PackageManager.pl',
-    },
+# get file version
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.10 $) [1];
+
+# common objects
+my %CommonObject = ();
+$CommonObject{ConfigObject} = Kernel::Config->new();
+$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
+$CommonObject{LogObject}    = Kernel::System::Log->new(
+    LogPrefix => 'OTRS-otrs.PackageManager.pl',
+    %CommonObject,
 );
+$CommonObject{MainObject}    = Kernel::System::Main->new(%CommonObject);
+$CommonObject{TimeObject}    = Kernel::System::Time->new(%CommonObject);
+$CommonObject{DBObject}      = Kernel::System::DB->new(%CommonObject);
+$CommonObject{PackageObject} = Kernel::System::Package->new(%CommonObject);
 
 # get options
 my %Opts;
-getopt( 'apodv', \%Opts );
+getopt( 'hapofdv', \%Opts );
 
 # set defaults
 if ( !$Opts{o} ) {
@@ -54,7 +71,7 @@ if ( !$Opts{f} ) {
 if ( !$Opts{a} ) {
     $Opts{h} = 1;
 }
-if ( $Opts{a} && ( $Opts{a} !~ /^(list|reinstall-all)/ && !$Opts{p} ) ) {
+if ( $Opts{a} && ( $Opts{a} !~ /^list/ && !$Opts{p} ) ) {
     $Opts{h} = 1;
 }
 if ( $Opts{a} && ( $Opts{a} eq 'exportfile' && ( !$Opts{p} || !$Opts{d} ) ) ) {
@@ -66,22 +83,17 @@ if ( $Opts{a} && $Opts{a} eq 'index' ) {
 
 # check needed params
 if ( $Opts{h} ) {
-    print "otrs.PackageManager.pl - OTRS Package Manager\n";
-    print "Copyright (C) 2001-2015 OTRS AG, http://otrs.com/\n";
+    print "otrs.PackageManager.pl <Revision $VERSION> - OTRS Package Manager\n";
+    print "Copyright (C) 2001-2014 OTRS AG, http://otrs.com/\n";
     print
-        "usage: otrs.PackageManager.pl -a list|install|upgrade|uninstall|reinstall|reinstall-all|list-repository|file|build|index \n";
+        "usage: otrs.PackageManager.pl -a list|install|upgrade|uninstall|reinstall|list-repository|file|build|index \n";
     print
         "      [-p package.opm|package.sopm|package|package-version] [-o OUTPUTDIR] [-f FORCE]\n";
     print " user (local):\n";
     print "   otrs.PackageManager.pl -a list\n";
-    print "   otrs.PackageManager.pl -a list -p Package\n";
-    print "   otrs.PackageManager.pl -a list -i\n";
-    print "   otrs.PackageManager.pl -a list -i -p Package\n";
-    print "   otrs.PackageManager.pl -a listinstalledfiles\n";
     print "   otrs.PackageManager.pl -a install -p /path/to/Package-1.0.0.opm\n";
     print "   otrs.PackageManager.pl -a upgrade -p /path/to/Package-1.0.1.opm\n";
     print "   otrs.PackageManager.pl -a reinstall -p Package\n";
-    print "   otrs.PackageManager.pl -a reinstall-all\n";
     print "   otrs.PackageManager.pl -a uninstall -p Package\n";
     print "   otrs.PackageManager.pl -a file -p Kernel/System/File.pm (find package of file)\n";
     print
@@ -107,7 +119,7 @@ if ( $Opts{h} ) {
 my $FileString = '';
 if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
     if ( -e $Opts{p} ) {
-        my $ContentRef = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
+        my $ContentRef = $CommonObject{MainObject}->FileRead(
             Location => $Opts{p},
             Mode     => 'utf8',      # optional - binmode|utf8
             Result   => 'SCALAR',    # optional - SCALAR|ARRAY
@@ -123,11 +135,8 @@ if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
         my $URL         = $1;
         my $PackageName = $2;
         if ( $URL eq 'online' ) {
-            my %List = %{ $Kernel::OM->Get('Kernel::Config')->Get('Package::RepositoryList') };
-            %List = (
-                %List,
-                $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineRepositories()
-            );
+            my %List = %{ $CommonObject{ConfigObject}->Get('Package::RepositoryList') };
+            %List = ( %List, $CommonObject{PackageObject}->PackageOnlineRepositories() );
             for ( sort keys %List ) {
                 if ( $List{$_} =~ /^\[-Master-\]/ ) {
                     $URL = $_;
@@ -135,19 +144,18 @@ if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
             }
         }
         if ( $PackageName !~ /^.+?.opm$/ ) {
-            my @Packages = $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineList(
+            my @Packages = $CommonObject{PackageObject}->PackageOnlineList(
                 URL  => $URL,
-                Lang => $Kernel::OM->Get('Kernel::Config')->Get('DefaultLanguage'),
+                Lang => $CommonObject{ConfigObject}->Get('DefaultLanguage'),
             );
-            PACKAGE:
             for my $Package (@Packages) {
                 if ( $Package->{Name} eq $PackageName ) {
                     $PackageName = $Package->{File};
-                    last PACKAGE;
+                    last;
                 }
             }
         }
-        $FileString = $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineGet(
+        $FileString = $CommonObject{PackageObject}->PackageOnlineGet(
             Source => $URL,
             File   => $PackageName,
         );
@@ -157,20 +165,19 @@ if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
     }
     else {
         if ( $Opts{p} =~ /^(.*)\-(\d{1,4}\.\d{1,4}\.\d{1,4})$/ ) {
-            $FileString = $Kernel::OM->Get('Kernel::System::Package')->RepositoryGet(
+            $FileString = $CommonObject{PackageObject}->RepositoryGet(
                 Name    => $1,
                 Version => $2,
             );
         }
         else {
-            PACKAGE:
-            for my $Package ( $Kernel::OM->Get('Kernel::System::Package')->RepositoryList() ) {
+            for my $Package ( $CommonObject{PackageObject}->RepositoryList() ) {
                 if ( $Opts{p} eq $Package->{Name}->{Content} ) {
-                    $FileString = $Kernel::OM->Get('Kernel::System::Package')->RepositoryGet(
+                    $FileString = $CommonObject{PackageObject}->RepositoryGet(
                         Name    => $Package->{Name}->{Content},
                         Version => $Package->{Version}->{Content},
                     );
-                    last PACKAGE;
+                    last;
                 }
             }
         }
@@ -184,17 +191,7 @@ if ( $Opts{a} !~ /^(list|file)/ && $Opts{p} ) {
 if ( $Opts{a} eq 'file' ) {
     $Opts{p} =~ s/\/\//\//g;
     my $Hit = 0;
-    PACKAGE:
-    for my $Package ( $Kernel::OM->Get('Kernel::System::Package')->RepositoryList() ) {
-
-        # just shown in list if PackageIsVisible flag is enable
-        if (
-            defined $Package->{PackageIsVisible}
-            && !$Package->{PackageIsVisible}->{Content}
-            )
-        {
-            next PACKAGE;
-        }
+    for my $Package ( $CommonObject{PackageObject}->RepositoryList() ) {
         for my $File ( @{ $Package->{Filelist} } ) {
             if ( $Opts{p} =~ /^\Q$File->{Location}\E$/ ) {
                 print
@@ -227,7 +224,7 @@ if ( $Opts{a} eq 'exportfile' ) {
 
     # read package
     if ( -e $Opts{p} ) {
-        my $ContentRef = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
+        my $ContentRef = $CommonObject{MainObject}->FileRead(
             Location => $Opts{p},
             Mode     => 'utf8',      # optional - binmode|utf8
             Result   => 'SCALAR',    # optional - SCALAR|ARRAY
@@ -251,27 +248,13 @@ if ( $Opts{a} eq 'exportfile' ) {
         exit 1;
     }
 
-    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
-        String => $String,
-    );
-
-    # just export files if PackageIsDownloadable flag is enable
-    if (
-        defined $Structure{PackageIsDownloadable}
-        && !$Structure{PackageIsDownloadable}->{Content}
-        )
-    {
-        print STDERR "ERROR: Not possible to export files!\n";
-        exit 1;
-    }
-
     # export it
     print "+----------------------------------------------------------------------------+\n";
     print "| Export files of:\n";
     print "| Package: $Opts{p}\n";
     print "| To:      $Opts{d}\n";
     print "+----------------------------------------------------------------------------+\n";
-    $Kernel::OM->Get('Kernel::System::Package')->PackageExport(
+    $CommonObject{PackageObject}->PackageExport(
         String => $String,
         Home   => $Opts{d},
     );
@@ -280,20 +263,7 @@ if ( $Opts{a} eq 'exportfile' ) {
 
 # build
 if ( $Opts{a} eq 'build' ) {
-    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
-        String => $FileString,
-    );
-
-    # just build it if PackageIsDownloadable flag is enable
-    if (
-        defined $Structure{PackageIsDownloadable}
-        && !$Structure{PackageIsDownloadable}->{Content}
-        )
-    {
-        print STDERR "ERROR: Not available package!\n";
-        exit 1;
-    }
-
+    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
     if ( $Opts{v} && $Opts{v} =~ m/\d{1,4}\.\d{1,4}\.\d{1,4}/ ) {
         $Structure{Version}->{Content} = $Opts{v}
     }
@@ -317,8 +287,8 @@ if ( $Opts{a} eq 'build' ) {
     }
 
     my $Filename = $Structure{Name}->{Content} . '-' . $Structure{Version}->{Content} . '.opm';
-    my $Content  = $Kernel::OM->Get('Kernel::System::Package')->PackageBuild(%Structure);
-    my $File     = $Kernel::OM->Get('Kernel::System::Main')->FileWrite(
+    my $Content  = $CommonObject{PackageObject}->PackageBuild(%Structure);
+    my $File     = $CommonObject{MainObject}->FileWrite(
         Location   => $Opts{o} . '/' . $Filename,
         Content    => \$Content,
         Mode       => 'utf8',                       # binmode|utf8
@@ -338,29 +308,7 @@ elsif ( $Opts{a} eq 'uninstall' ) {
 
     # get package file from db
     # parse package
-    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
-        String => $FileString,
-    );
-
-    # just un-install it if PackageIsRemovable flag is enable
-    if (
-        defined $Structure{PackageIsRemovable}
-        && !$Structure{PackageIsRemovable}->{Content}
-        )
-    {
-        my $ExitMessage = "ERROR: Not possible to remove this package!\n";
-
-        # exchange message if package should not be visible
-        if (
-            defined $Structure{PackageIsVisible}
-            && !$Structure{PackageIsVisible}->{Content}
-            )
-        {
-            $ExitMessage = "ERROR: No such package!\n";
-        }
-        print STDERR $ExitMessage;
-        exit 1;
-    }
+    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
 
     # intro screen
     if ( $Structure{IntroUninstallPre} ) {
@@ -373,7 +321,7 @@ elsif ( $Opts{a} eq 'uninstall' ) {
     }
 
     # uninstall
-    $Kernel::OM->Get('Kernel::System::Package')->PackageUninstall(
+    $CommonObject{PackageObject}->PackageUninstall(
         String => $FileString,
         Force  => $Opts{f},
     );
@@ -392,9 +340,7 @@ elsif ( $Opts{a} eq 'uninstall' ) {
 elsif ( $Opts{a} eq 'install' ) {
 
     # parse package
-    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
-        String => $FileString,
-    );
+    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
 
     # intro screen
     if ( $Structure{IntroInstallPre} ) {
@@ -407,7 +353,7 @@ elsif ( $Opts{a} eq 'install' ) {
     }
 
     # install
-    $Kernel::OM->Get('Kernel::System::Package')->PackageInstall(
+    $CommonObject{PackageObject}->PackageInstall(
         String => $FileString,
         Force  => $Opts{f},
     );
@@ -426,9 +372,7 @@ elsif ( $Opts{a} eq 'install' ) {
 elsif ( $Opts{a} eq 'reinstall' ) {
 
     # parse package
-    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
-        String => $FileString,
-    );
+    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
 
     # intro screen
     if ( $Structure{IntroReinstallPre} ) {
@@ -441,7 +385,7 @@ elsif ( $Opts{a} eq 'reinstall' ) {
     }
 
     # install
-    $Kernel::OM->Get('Kernel::System::Package')->PackageReinstall(
+    $CommonObject{PackageObject}->PackageReinstall(
         String => $FileString,
         Force  => $Opts{f},
     );
@@ -457,54 +401,10 @@ elsif ( $Opts{a} eq 'reinstall' ) {
     }
     exit;
 }
-elsif ( $Opts{a} eq 'reinstall-all' ) {
-
-    my @ReinstalledPackages;
-
-    # loop all locally installed packages
-    for my $Package ( $Kernel::OM->Get('Kernel::System::Package')->RepositoryList() ) {
-
-        # do a deploy check to see if reinstallation is needed
-        my $ReinstallNeeded = $Kernel::OM->Get('Kernel::System::Package')->DeployCheck(
-            Name    => $Package->{Name}->{Content},
-            Version => $Package->{Version}->{Content},
-        );
-
-        if ( !$ReinstallNeeded ) {
-
-            push @ReinstalledPackages, $Package->{Name}->{Content};
-
-            my $FileString = $Kernel::OM->Get('Kernel::System::Package')->RepositoryGet(
-                Name    => $Package->{Name}->{Content},
-                Version => $Package->{Version}->{Content},
-            );
-
-            $Kernel::OM->Get('Kernel::System::Package')->PackageReinstall(
-                String => $FileString,
-                Force  => $Opts{f},
-            );
-        }
-    }
-
-    if (@ReinstalledPackages) {
-        for my $Package (@ReinstalledPackages) {
-            print "Reinstalled: $Package\n";
-        }
-        print "\n";
-    }
-    else {
-        print "No packages needed reinstallation.\n";
-    }
-
-    print "Done.\n";
-    exit;
-}
 elsif ( $Opts{a} eq 'upgrade' ) {
 
     # parse package
-    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
-        String => $FileString,
-    );
+    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
 
     # intro screen
     if ( $Structure{IntroUpgradePre} ) {
@@ -517,7 +417,7 @@ elsif ( $Opts{a} eq 'upgrade' ) {
     }
 
     # upgrade
-    $Kernel::OM->Get('Kernel::System::Package')->PackageUpgrade(
+    $CommonObject{PackageObject}->PackageUpgrade(
         String => $FileString,
         Force  => $Opts{f},
     );
@@ -534,28 +434,8 @@ elsif ( $Opts{a} eq 'upgrade' ) {
     exit;
 }
 elsif ( $Opts{a} eq 'list' ) {
-
-    PACKAGE:
-    for my $Package ( $Kernel::OM->Get('Kernel::System::Package')->RepositoryList() ) {
-
-        # just shown in list if PackageIsVisible flag is enable
-        if (
-            defined $Package->{PackageIsVisible}
-            && !$Package->{PackageIsVisible}->{Content}
-            )
-        {
-            next PACKAGE;
-        }
-
-        if ( defined $Opts{p} && length $Opts{p} ) {
-            my $PackageString = $Package->{Name}->{Content} . '-' . $Package->{Version}->{Content};
-            next PACKAGE if $PackageString !~ m{$Opts{p}}i;
-        }
-
-        my %Data = _MessageGet(
-            Info     => $Package->{Description},
-            Reformat => 'No'
-        );
+    for my $Package ( $CommonObject{PackageObject}->RepositoryList() ) {
+        my %Data = _MessageGet( Info => $Package->{Description}, Reformat => 'No' );
         print "+----------------------------------------------------------------------------+\n";
         print "| Name:        $Package->{Name}->{Content}\n";
         print "| Version:     $Package->{Version}->{Content}\n";
@@ -563,56 +443,17 @@ elsif ( $Opts{a} eq 'list' ) {
         print "| URL:         $Package->{URL}->{Content}\n";
         print "| License:     $Package->{License}->{Content}\n";
         print "| Description: $Data{Description}\n";
-
-        if ( defined $Opts{i} ) {
-
-            my $PackageDeploymentOK = $Kernel::OM->Get('Kernel::System::Package')->DeployCheck(
-                Name    => $Package->{Name}->{Content},
-                Version => $Package->{Version}->{Content},
-                Log     => 0,
-            );
-            print '| Deployment:  ' . ( $PackageDeploymentOK ? 'OK' : 'Not OK' ) . "\n";
-
-            my %PackageDeploymentInfo = $Kernel::OM->Get('Kernel::System::Package')->DeployCheckInfo();
-            if ( defined $PackageDeploymentInfo{File} && %{ $PackageDeploymentInfo{File} } ) {
-                for my $File ( sort keys %{ $PackageDeploymentInfo{File} } ) {
-                    my $FileMessage = $PackageDeploymentInfo{File}->{$File};
-                    print "| File Status: $File => $FileMessage\n";
-                }
-            }
-        }
     }
     print "+----------------------------------------------------------------------------+\n";
     exit;
 }
-elsif ( $Opts{a} eq 'listinstalledfiles' ) {
-    my @Packages = $Kernel::OM->Get('Kernel::System::Package')->RepositoryList();
-
-    PACKAGE:
-    for my $Package (@Packages) {
-
-        # Just show if PackageIsVisible flag is enabled.
-        if (
-            defined $Package->{PackageIsVisible}
-            && !$Package->{PackageIsVisible}->{Content}
-            )
-        {
-            next PACKAGE;
-        }
-
-        for my $File ( @{ $Package->{Filelist} } ) {
-            print "  $Package->{Name}->{Content}: $File->{Location}\n";
-        }
-    }
-    exit;
-}
 elsif ( $Opts{a} eq 'list-repository' ) {
     my $Count = 0;
-    my %List;
-    if ( $Kernel::OM->Get('Kernel::Config')->Get('Package::RepositoryList') ) {
-        %List = %{ $Kernel::OM->Get('Kernel::Config')->Get('Package::RepositoryList') };
+    my %List  = ();
+    if ( $CommonObject{ConfigObject}->Get('Package::RepositoryList') ) {
+        %List = %{ $CommonObject{ConfigObject}->Get('Package::RepositoryList') };
     }
-    %List = ( %List, $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineRepositories() );
+    %List = ( %List, $CommonObject{PackageObject}->PackageOnlineRepositories() );
     for my $URL ( sort { $List{$a} cmp $List{$b} } keys %List ) {
         $Count++;
         print "+----------------------------------------------------------------------------+\n";
@@ -633,22 +474,12 @@ elsif ( $Opts{a} eq 'list-repository' ) {
             print
                 "+----------------------------------------------------------------------------+\n";
             print "| Package Overview:\n";
-            my @Packages = $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineList(
+            my @Packages = $CommonObject{PackageObject}->PackageOnlineList(
                 URL  => $URL,
-                Lang => $Kernel::OM->Get('Kernel::Config')->Get('DefaultLanguage'),
+                Lang => $CommonObject{ConfigObject}->Get('DefaultLanguage'),
             );
             my $Count = 0;
-            PACKAGE:
             for my $Package (@Packages) {
-
-                # just shown in list if PackageIsVisible flag is enable
-                if (
-                    defined $Package->{PackageIsVisible}
-                    && !$Package->{PackageIsVisible}->{Content}
-                    )
-                {
-                    next PACKAGE;
-                }
                 $Count++;
                 print
                     "+----------------------------------------------------------------------------+\n";
@@ -669,11 +500,11 @@ elsif ( $Opts{a} eq 'list-repository' ) {
             for my $Package (@Packages) {
                 $Count++;
                 if ( $Count eq $PackageCount ) {
-                    my $FileString = $Kernel::OM->Get('Kernel::System::Package')->PackageOnlineGet(
+                    my $FileString = $CommonObject{PackageObject}->PackageOnlineGet(
                         Source => $URL,
                         File   => $Package->{File},
                     );
-                    $Kernel::OM->Get('Kernel::System::Package')->PackageInstall(
+                    $CommonObject{PackageObject}->PackageInstall(
                         String => $FileString,
                         Force  => $Opts{'f'},
                     );
@@ -684,59 +515,13 @@ elsif ( $Opts{a} eq 'list-repository' ) {
     exit;
 }
 elsif ( $Opts{a} eq 'p' ) {
-
-    # parse package
-    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
-        String => $FileString,
-    );
-
-    # perform parsing only if PackageIsVisible flag is enable
-    if (
-        defined $Structure{PackageIsVisible}
-        && !$Structure{PackageIsVisible}->{Content}
-        )
-    {
-        print STDERR "ERROR: no such package $Opts{p}!\n";
-        exit 1;
-    }
-
-    my @Data = keys %Structure;
+    my @Data = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
     for my $Tag (@Data) {
-        if ( ref $Structure{$Tag} eq 'HASH' ) {
-            print STDERR "Tag: $Structure{$Tag}->{TagType} - $Structure{$Tag}->{Tag} $Structure{$Tag}->{Content}\n";
-        }
-        elsif ( ref $Structure{$Tag} eq 'ARRAY' ) {
-
-            # add a sub-level reference
-            print STDERR "\n--- Open Sub-Tag: $Tag ---\n";
-
-            # loop over the second level tags
-            my @SubData = @{ $Structure{$Tag} };
-            for my $SubTag (@SubData) {
-                print STDERR "Tag: $SubTag->{TagType} $SubTag->{Tag} $SubTag->{Content}\n";
-            }
-
-            # add a sub-level reference
-            print STDERR "--- Close Sub-Tag: $Tag ---\n\n";
-        }
+        print STDERR "Tag: $Tag->{Type} $Tag->{Tag} $Tag->{Content}\n";
     }
-
 }
 elsif ( $Opts{a} eq 'parse' ) {
-    my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse(
-        String => $FileString,
-    );
-
-    # perform parsing only if PackageIsVisible flag is enable
-    if (
-        defined $Structure{PackageIsVisible}
-        && !$Structure{PackageIsVisible}->{Content}
-        )
-    {
-        print STDERR "ERROR: no such package $Opts{p}!\n";
-        exit 1;
-    }
-
+    my %Structure = $CommonObject{PackageObject}->PackageParse( String => $FileString, );
     for my $Key ( sort keys %Structure ) {
         if ( ref( $Structure{$Key} ) eq 'ARRAY' ) {
             for my $Data ( @{ $Structure{$Key} } ) {
@@ -768,7 +553,7 @@ elsif ( $Opts{a} eq 'index' ) {
     elsif ( !-d $Opts{d} ) {
         die "ERROR: invalid package root location '$Opts{d}'";
     }
-    my @Dirs;
+    my @Dirs = ();
     print "<?xml version=\"1.0\" encoding=\"utf-8\" ?>\n";
     print "<otrs_package_list version=\"1.0\">\n";
     BuildPackageIndex( $Opts{d} );
@@ -782,7 +567,7 @@ else {
 sub BuildPackageIndex {
     my $In = shift;
 
-    my @List = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
+    my @List = $CommonObject{MainObject}->DirectoryRead(
         Directory => $In,
         Filter    => '*',
     );
@@ -792,19 +577,19 @@ sub BuildPackageIndex {
             BuildPackageIndex($File);
             $File =~ s/$Opts{d}//;
 
-            # print "Directory: $File\n";
+            #            print "Directory: $File\n";
         }
         else {
             my $OrigFile = $File;
             $File =~ s/$Opts{d}//;
 
-            # print "File: $File\n";
-            # my $Dir =~ s/^(.*)\//$1/;
+            #               print "File: $File\n";
+            #               my $Dir =~ s/^(.*)\//$1/;
             if ( $File !~ /Entries|Repository|Root|CVS/ && $File =~ /\.opm$/ ) {
 
-                # print "F: $File\n";
+                #               print "F: $File\n";
                 my $Content    = '';
-                my $ContentRef = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
+                my $ContentRef = $CommonObject{MainObject}->FileRead(
                     Location => $OrigFile,
                     Mode     => 'utf8',      # optional - binmode|utf8
                     Result   => 'SCALAR',    # optional - SCALAR|ARRAY
@@ -813,8 +598,9 @@ sub BuildPackageIndex {
                     print STDERR "ERROR: Can't open $OrigFile: $!\n";
                     exit 1;
                 }
-                my %Structure = $Kernel::OM->Get('Kernel::System::Package')->PackageParse( String => ${$ContentRef} );
-                my $XML = $Kernel::OM->Get('Kernel::System::Package')->PackageBuild( %Structure, Type => 'Index' );
+                my %Structure
+                    = $CommonObject{PackageObject}->PackageParse( String => ${$ContentRef} );
+                my $XML = $CommonObject{PackageObject}->PackageBuild( %Structure, Type => 'Index' );
                 print "<Package>\n";
                 print $XML;
                 print "  <File>$File</File>\n";
