@@ -1,6 +1,10 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# webform.pl - a simple web form script to generate email with
+# X-OTRS-Queue header for an OTRS system (x-headers for dispatching!).
+# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# --
+# $Id: webform.pl,v 1.14 2009-02-20 12:05:54 mh Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +13,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -27,9 +31,11 @@ use CGI::Carp qw(fatalsToBrowser);
 # Simple Common Gateway Interface Class
 use CGI;
 
-#
+my $VERSION = qw($Revision: 1.14 $) [1];
+
+# --------------------------
 # web form options
-#
+# --------------------------
 my $Ident = 'ahfiw2Fw32r230dddl2foeo3r';
 
 # sendmail location and options
@@ -50,9 +56,9 @@ my %Topics = (
     'Webmaster' => 'webmaster',
 );
 
-#
+# --------------------------
 # html header
-#
+# --------------------------
 
 sub Header {
     my (%Param) = @_;
@@ -77,9 +83,9 @@ EOF
     return $Output;
 }
 
-#
+# -------------------------
 # html footer
-#
+# -------------------------
 
 sub Footer {
     my $Output = <<EOF;
@@ -91,9 +97,9 @@ EOF
     return $Output;
 }
 
-#
+# -------------------------
 # Thanks
-#
+# -------------------------
 
 sub Thanks {
     my (%Param) = @_;
@@ -110,9 +116,9 @@ EOF
     return $Output;
 }
 
-#
+# ----------------------
 # error
-#
+# ----------------------
 
 sub Error {
     my (%Param) = @_;
@@ -128,9 +134,9 @@ EOF
     return $Output;
 }
 
-#
+# ------------------------
 # start the real actions
-#
+# ------------------------
 my $CGI      = new CGI;
 my %GetParam = ();
 for (qw(Action From FromEmail Subject Topic Body)) {
@@ -145,9 +151,9 @@ else {
     WebForm();
 }
 
-#
+# ------------------------
 # web form
-#
+# ------------------------
 sub WebForm {
     print Header( Title => 'Submit Request' );
     print '
@@ -192,9 +198,9 @@ sub WebForm {
     print Footer();
 }
 
-#
+# --------------------------
 # send email
-#
+# --------------------------
 
 sub SendMail {
     my (%Param) = @_;
@@ -248,7 +254,7 @@ sub SendMail {
     push @Mail, "X-OTRS-ArticleValue1: Webform\n";
     push @Mail, "X-OTRS-ArticleKey2: Orig. sort\n";
     push @Mail, "X-OTRS-ArticleValue2: $Param{Topic}\n";
-    push @Mail, "X-Mailer: OTRS WebForm\n";
+    push @Mail, "X-Mailer: OTRS WebForm ($VERSION)\n";
     push @Mail, "X-Powered-By: OTRS (http://otrs.org/)\n";
     push @Mail, "\n";
     push @Mail, $Param{Body};
@@ -258,7 +264,7 @@ sub SendMail {
     my $FromEmail = $Param{FromEmail};
     $FromEmail =~ s/"|;|'|<|>|\||\s|\r|\n|\t|`//ig;
     $FromEmail = quotemeta $FromEmail;
-    if ( open my $Mail, '|-', "$Sendmail $FromEmail" ) {    ## no critic
+    if ( open my $Mail, '|-', "$Sendmail $FromEmail" ) {
         print $Mail @Mail;
         close $Mail;
 
